"""FastAPI shim exposing the canonical Passwordless health router."""

from __future__ import annotations

from typing import Any

from src.health.passwordless import (
    passwordless_health_check,
    register_passwordless_health,
    router as passwordless_health_router,
)


def build_health_router() -> Any:
    """Return the generated Passwordless health router."""

    return passwordless_health_router


router = passwordless_health_router

__all__ = [
    "build_health_router",
    "passwordless_health_check",
    "register_passwordless_health",
    "router",
]
