# Default Users Profiles configuration generated by RapidKit
users_profiles:
  module: {{ module_name | tojson }}
  title: {{ module_title | tojson }}
  default_timezone: {{ users_profiles_defaults.get('default_timezone', 'UTC') | tojson }}
  max_bio_length: {{ users_profiles_defaults.get('max_bio_length', 280) | tojson }}
  avatar_max_bytes: {{ users_profiles_defaults.get('avatar_max_bytes', 2_097_152) | tojson }}
  allow_marketing_opt_in: {{ users_profiles_defaults.get('allow_marketing_opt_in', True) | tojson }}
  social_links_limit: {{ users_profiles_defaults.get('social_links_limit', 5) | tojson }}
  default_visibility: {{ users_profiles_defaults.get('default_visibility', 'public') | tojson }}
  supported_visibilities: {{ users_profiles_defaults.get('supported_visibilities', ['public', 'private', 'team']) | tojson(indent=2) }}
