# Default SQLite configuration generated by RapidKit
sqlite:
  module: {{ rapidkit_vendor_module | tojson }}
  enabled: {{ enabled_by_default | tojson }}
  database:
    path: {{ default_database_path | tojson }}
    create_if_missing: {{ default_create_if_missing | tojson }}
    timeout_seconds: {{ default_timeout_seconds | tojson }}
    isolation_level: {{ default_isolation_level | tojson }}
    detect_types: {{ default_detect_types | tojson }}
    check_same_thread: {{ default_check_same_thread | tojson }}
  pragmas:
{% for key, value in default_pragmas | dictsort %}    {{ key }}: {{ value | tojson }}
{% endfor %}
  pool:
    max_size: {{ default_pool.max_size | tojson }}
    recycle_seconds: {{ default_pool.recycle_seconds | tojson }}
  retry:
    attempts: {{ default_retry_attempts | tojson }}
