import { Module } from "@nestjs/common";

import { {{ module_class_name }}Module } from "../modules/free/users/users_core/users-core.module";
import { {{ module_class_name }}HealthController } from "./users-core-health.controller";

@Module({
  imports: [{{ module_class_name }}Module],
  controllers: [{{ module_class_name }}HealthController],
})
export class {{ module_class_name }}HealthModule {}
