import { Module } from '@nestjs/common';
import { DeploymentService } from '../deployment/deployment.service';
import { DeploymentHealthController } from './deployment-health.controller';

@Module({
  controllers: [DeploymentHealthController],
  providers: [DeploymentService],
})
export class DeploymentHealthModule {}
export class DeploymentModule {}
