import { Controller, Get } from "@nestjs/common";

import { {{ module_class_name }}Service } from "./{{ module_name }}.service";

@Controller("{{ module_kebab }}")
export class {{ module_class_name }}Controller {
  constructor(private readonly service: {{ module_class_name }}Service) {}

  @Get("health")
  getHealth(): Record<string, unknown> {
    return this.service.getHealth();
  }

  @Get("metadata")
  getMetadata(): Record<string, unknown> {
    return this.service.getMetadata();
  }

  @Get("discounts")
  listDiscounts(): Record<string, unknown> {
    return {
      discounts: this.service.listDiscounts(),
    };
  }

  @Get("status")
  getStatus(): Record<string, unknown> {
    return this.service.getStatus();
  }
}
