# PostgreSQL module environment defaults
RAPIDKIT_DB_POSTGRES_URL=${RAPIDKIT_DB_POSTGRES_URL:-postgresql://postgres:postgres@localhost:5432/app_db}
RAPIDKIT_DB_POSTGRES_TEST_URL=${RAPIDKIT_DB_POSTGRES_TEST_URL:-postgresql://postgres:postgres@localhost:5433/app_db_test}
RAPIDKIT_DB_POSTGRES_POOL_SIZE=${RAPIDKIT_DB_POSTGRES_POOL_SIZE:-10}
RAPIDKIT_DB_POSTGRES_MAX_OVERFLOW=${RAPIDKIT_DB_POSTGRES_MAX_OVERFLOW:-20}
RAPIDKIT_DB_POSTGRES_POOL_TIMEOUT=${RAPIDKIT_DB_POSTGRES_POOL_TIMEOUT:-30}
RAPIDKIT_DB_POSTGRES_POOL_RECYCLE=${RAPIDKIT_DB_POSTGRES_POOL_RECYCLE:-3600}
RAPIDKIT_DB_POSTGRES_ECHO=${RAPIDKIT_DB_POSTGRES_ECHO:-false}
