import { Injectable } from '@nestjs/common';
import { HealthIndicator, HealthIndicatorResult } from '@nestjs/terminus';

@Injectable()
export class LoggingHealthIndicator extends HealthIndicator {
  public async isHealthy(): Promise<HealthIndicatorResult> {
    return this.getStatus('logging', true);
  }
}
