# Default Users Core configuration generated by RapidKit
users_core:
  module: {{ module_name | tojson }}
  title: {{ module_title | tojson }}
  allow_registration: {{ users_core_defaults.get('allow_registration', True) | tojson }}
  enforce_unique_email: {{ users_core_defaults.get('enforce_unique_email', True) | tojson }}
  default_locale: {{ users_core_defaults.get('default_locale', 'en') | tojson }}
  audit_log_enabled: {{ users_core_defaults.get('audit_log_enabled', True) | tojson }}
  max_results_per_page: {{ users_core_defaults.get('max_results_per_page', 100) | tojson }}
  passwordless_supported: {{ users_core_defaults.get('passwordless_supported', False) | tojson }}
  supported_locales: {{ users_core_defaults.get('supported_locales', ['en']) | tojson(indent=2) }}
