# Redis module environment variables
REDIS_URL={{ redis_defaults.url | default('redis://localhost:6379/0') }}
REDIS_HOST={{ redis_defaults.host | default('localhost') }}
REDIS_PORT={{ redis_defaults.port | default(6379) }}
REDIS_DB={{ redis_defaults.db | default(0) }}
REDIS_PASSWORD={{ redis_defaults.password | default('') }}
REDIS_USE_TLS={{ redis_defaults.use_tls | default(false) | tojson }}
CACHE_TTL={{ redis_defaults.cache_ttl | default(3600) }}
REDIS_PRECONNECT={{ redis_defaults.preconnect | default(false) | tojson }}
REDIS_CONNECT_RETRIES={{ redis_defaults.connect_retries | default(3) }}
REDIS_CONNECT_BACKOFF_BASE={{ redis_defaults.connect_backoff_base | default(0.5) }}
