"""FastAPI router re-exports for passwordless module."""

from __future__ import annotations

from fastapi import APIRouter

from src.modules.free.auth.passwordless.passwordless import create_router, get_runtime


def build_router() -> APIRouter:
    return create_router()


router = build_router()


__all__ = ["create_router", "build_router", "get_runtime", "router"]
