  RATE_LIMIT_ENABLED?: boolean;
  RATE_LIMIT_BACKEND?: string;
  RATE_LIMIT_REDIS_URL?: string | null;
  RATE_LIMIT_REDIS_PREFIX?: string;
  RATE_LIMIT_TRUST_FORWARDED_FOR?: boolean;
  RATE_LIMIT_FORWARDED_FOR_HEADER?: string;
  RATE_LIMIT_IDENTITY_HEADER?: string | null;
  RATE_LIMIT_DEFAULT_RULE_NAME?: string;
  RATE_LIMIT_DEFAULT_LIMIT?: number;
  RATE_LIMIT_DEFAULT_WINDOW?: number;
  RATE_LIMIT_DEFAULT_SCOPE?: string;
  RATE_LIMIT_DEFAULT_PRIORITY?: number;
  RATE_LIMIT_DEFAULT_BLOCK_SECONDS?: number | null;
  RATE_LIMIT_HEADER_LIMIT?: string;
  RATE_LIMIT_HEADER_REMAINING?: string;
  RATE_LIMIT_HEADER_RESET?: string;
  RATE_LIMIT_HEADER_RETRY_AFTER?: string;
  RATE_LIMIT_HEADER_RULE?: string;
  RATE_LIMIT_RULES_JSON?: string;
