# Default PostgreSQL configuration generated by RapidKit
postgres:
  module: {{ rapidkit_vendor_module | tojson }}
  enabled: {{ database_defaults.get('enabled', True) | tojson }}
  url: {{ database_defaults.get('database_url') | tojson }}
  test_url: {{ database_defaults.get('test_database_url') | tojson }}
  schema: {{ database_defaults.get('schema', 'public') | tojson }}
  echo: {{ database_defaults.get('echo', False) | tojson }}
  expire_on_commit: {{ database_defaults.get('expire_on_commit', False) | tojson }}
  pool:
    size: {{ database_defaults.get('pool_size', 10) | tojson }}
    max_overflow: {{ database_defaults.get('max_overflow', 20) | tojson }}
    recycle_seconds: {{ database_defaults.get('pool_recycle', 3600) | tojson }}
    timeout_seconds: {{ database_defaults.get('pool_timeout', 30) | tojson }}
  metadata: {{ database_defaults.get('metadata', {}) | tojson(indent=2) }}
