"""Core engine components for RapidKit.

This module contains the core engine functionality including:
- Kit registry and management
- Dependency installation
- Project generation
- Module installation
"""

from typing import List as _List

__all__: _List[str] = []
