# Storage Module Environment Variables
STORAGE_ADAPTER={{ storage_adapter | default('local') }}
STORAGE_BASE_PATH={{ storage_base_path | default('./storage/uploads') }}
STORAGE_MAX_FILE_SIZE={{ storage_max_file_size | default(104857600) }}
S3_BUCKET={{ s3_bucket | default('') }}
S3_REGION={{ s3_region | default('us-east-1') }}
GCS_BUCKET={{ gcs_bucket | default('') }}
STORAGE_IMAGE_PROCESSING={{ storage_image_processing | default('true') }}
STORAGE_SCAN_ON_UPLOAD={{ storage_scan_on_upload | default('true') }}
