  LOG_LEVEL?: string;

  LOG_FORMAT?: "json" | "text" | "colored";

  LOG_SINKS?: string | string[];

  LOG_ASYNC_QUEUE?: boolean;

  LOG_FILE_PATH?: string;

  LOG_SAMPLING_RATE?: number;

  LOG_ENABLE_REDACTION?: boolean;

  ENABLE_CORRELATION_IDS?: boolean;

  CORRELATION_ID_HEADER?: string;

  ENABLE_USER_CONTEXT?: boolean;

  ENABLE_SAMPLING?: boolean;

  JSON_INDENT?: number;

  OTEL_BRIDGE_ENABLED?: boolean;

  METRICS_BRIDGE_ENABLED?: boolean;

  LOGGING_HEALTHCHECK_ENABLED?: boolean;

  LOGGING_HEALTHCHECK_PATH?: string;

  RAPIDKIT_LOGGING_REQUEST_CONTEXT?: boolean;
