# Session Module Environment Variables
{% set defaults = session_defaults %}
{{ defaults.secret_key_env | default('RAPIDKIT_SESSION_SECRET') }}="please-set-a-secure-random-value"
SESSION_TTL_SECONDS={{ defaults.session_ttl_seconds | default(2592000) }}
SESSION_REFRESH_TTL_SECONDS={{ defaults.refresh_ttl_seconds | default(15552000) }}
SESSION_COOKIE_NAME={{ defaults.cookie_name | default('rapidkit_session') }}
SESSION_COOKIE_DOMAIN={{ defaults.cookie_domain | default('') }}
SESSION_COOKIE_SECURE={{ 'true' if defaults.cookie_secure | default(true) else 'false' }}
SESSION_COOKIE_HTTPONLY={{ 'true' if defaults.cookie_httponly | default(true) else 'false' }}
SESSION_COOKIE_SAME_SITE={{ defaults.cookie_same_site | default('lax') }}
SESSION_STORAGE_BACKEND={{ defaults.storage_backend | default('memory') }}
