import { Module } from '@nestjs/common';

import { ExamplesController } from './examples.controller';
import { ExamplesService } from './examples.service';

@Module({
  controllers: [ExamplesController],
  providers: [ExamplesService],
})
export class ExamplesModule {}
