# Default Logging configuration generated by RapidKit
logging:
  level: {{ logging_defaults.get('level', 'INFO') | tojson }}
  format: {{ logging_defaults.get('format', 'json') | tojson }}
  sinks: {{ logging_defaults.get('sinks', ['stderr']) | tojson }}
  async_queue: {{ logging_defaults.get('async_queue', True) | tojson }}
  file_path: {{ logging_defaults.get('file_path', 'logs/app.log') | tojson }}
  sampling_rate: {{ logging_defaults.get('sampling_rate', 1.0) | tojson }}
  enable_redaction: {{ logging_defaults.get('enable_redaction', True) | tojson }}
  otel_bridge_enabled: {{ logging_defaults.get('otel_bridge_enabled', False) | tojson }}
  metrics_bridge_enabled: {{ logging_defaults.get('metrics_bridge_enabled', False) | tojson }}
  request_context_enabled: {{ logging_request_context_enabled | default(True) | tojson }}
