# OAuth Module Environment Variables
{% set defaults = oauth_defaults %}
OAUTH_REDIRECT_BASE_URL={{ defaults.redirect_base_url | default('https://example.com/oauth') }}
OAUTH_STATE_TTL_SECONDS={{ defaults.state_ttl_seconds | default(300) }}
OAUTH_STATE_CLEANUP_INTERVAL={{ defaults.state_cleanup_interval | default(60) }}
{% for name, provider in (defaults.providers or {}).items() %}
{{ provider.client_id_env | default(name | upper ~ '_OAUTH_CLIENT_ID') }}=""
{{ provider.client_secret_env | default(name | upper ~ '_OAUTH_CLIENT_SECRET') }}=""
{% endfor %}
