# RapidKit environment defaults
PROJECT_NAME="{{ project_name | default('rapidkit-app') }}"
ENV="development"
DEBUG="true"
APP_HOST="0.0.0.0"
APP_PORT="8000"
LOG_LEVEL="info"

# Module-specific environment variables
# <<<inject:module-env>>>
