# Default Redis configuration scaffold generated by RapidKit
redis:
  url: {{ redis_defaults.url | default('redis://localhost:6379/0') | tojson }}
  preconnect: {{ redis_defaults.preconnect | default(false) | tojson }}
  connect_retries: {{ redis_defaults.connect_retries | default(3) }}
  connect_backoff_base: {{ redis_defaults.connect_backoff_base | default(0.5) }}
  cache_ttl: {{ redis_defaults.cache_ttl | default(3600) }}
  use_tls: {{ redis_defaults.use_tls | default(false) | tojson }}
