import { Controller, Get } from "@nestjs/common";

import {
  UsersCoreFeature,
  UsersCoreMetadata,
  {{ module_class_name }}Service,
} from "./users-core.service";

@Controller("users-core")
export class {{ module_class_name }}Controller {
  constructor(private readonly service: {{ module_class_name }}Service) {}

  @Get("metadata")
  getMetadata(): UsersCoreMetadata {
    return this.service.buildMetadata();
  }

  @Get("features")
  listFeatures(): { features: UsersCoreFeature[] } {
    return { features: this.service.listFeatures() };
  }

}
