from pathlib import Path


def test_generator_entrypoint() -> None:
    """Smoky assertion ensuring generator is importable."""

    module_root = Path(__file__).resolve().parents[3]
    assert module_root.exists()
