import { Type } from "@nestjs/common";

import { AuthCoreController } from "./auth-core.controller";
import { AuthCoreHealthController } from "../../../../health/auth-core.health";

export const AUTH_CORE_ROUTES: Type[] = [AuthCoreController, AuthCoreHealthController];
