# Default Email configuration generated by RapidKit
email:
  enabled: {{ email_defaults.get('enabled', true) | tojson }}
  provider: {{ email_defaults.get('provider', 'smtp') | tojson }}
  from_email: {{ email_defaults.get('from_email', 'noreply@rapidkit.top') | tojson }}
  from_name: {{ email_defaults.get('from_name', 'RapidKit') | tojson }}
  reply_to: {{ email_defaults.get('reply_to') | tojson }}
  dry_run: {{ email_defaults.get('dry_run', false) | tojson }}
  default_headers: {{ email_defaults.get('default_headers', {}) | tojson }}
  metadata: {{ email_defaults.get('metadata', {}) | tojson }}
  smtp:
    {% set smtp_defaults = email_defaults.get('smtp', {}) %}
    host: {{ smtp_defaults.get('host', 'localhost') | tojson }}
    port: {{ smtp_defaults.get('port', 1025) }}
    username: {{ smtp_defaults.get('username') | tojson }}
    password: {{ smtp_defaults.get('password') | tojson }}
    use_tls: {{ smtp_defaults.get('use_tls', false) | tojson }}
    timeout_seconds: {{ smtp_defaults.get('timeout_seconds', 30) | tojson }}
  template:
    {% set template_defaults = email_defaults.get('template', {}) %}
    directory: {{ template_defaults.get('directory', 'templates/email') | tojson }}
    auto_reload: {{ template_defaults.get('auto_reload', false) | tojson }}
    strict: {{ template_defaults.get('strict', false) | tojson }}
