"use strict";

function loadConfiguration() {
  return {
    module: "celery",
    title: "Celery",
    enabled: true,
    connection: {
      brokerUrl: process.env.RAPIDKIT_CELERY_BROKER_URL || "redis://localhost:6379/0",
      resultBackend: process.env.RAPIDKIT_CELERY_RESULT_BACKEND || "redis://localhost:6379/1",
      defaultQueue: process.env.RAPIDKIT_CELERY_DEFAULT_QUEUE || "default",
    },
    defaultHeaders: {
      "X-RapidKit-Module": "celery",
    },
  };
}

module.exports = {
  loadConfiguration,
};
