"""Convenience facade mirroring src.modules.free.cache.redis exports."""

from src.modules.free.cache.redis.client import (  # type: ignore[no-redef]
    AsyncRedis,
    DEFAULTS,
    RedisClient,
    RedisSyncClient,
    SyncRedis,
    build_redis_url,
    check_redis_connection,
    get_redis,
    get_redis_metadata,
    get_redis_sync,
    redis_dependency,
    refresh_vendor_module,
    register_redis,
)
from src.modules.free.cache.redis.runtime import describe_cache, list_features  # type: ignore[import]

__all__ = [
    "AsyncRedis",
    "SyncRedis",
    "RedisClient",
    "RedisSyncClient",
    "DEFAULTS",
    "build_redis_url",
    "check_redis_connection",
    "get_redis",
    "get_redis_sync",
    "redis_dependency",
    "register_redis",
    "refresh_vendor_module",
    "get_redis_metadata",
    "describe_cache",
    "list_features",
]
