import { Type } from "@nestjs/common";

import { OauthController } from "./oauth.controller";
import { OauthHealthController } from "../../../../health/oauth.health";

export const OAUTH_ROUTES: Type[] = [OauthController, OauthHealthController];
