import { Injectable } from "@nestjs/common";

@Injectable()
export class {{ module_class_name }}Service {
  getStatus(): Record<string, string> {
    return { module: "{{ module_name }}", status: "ok" };
  }
}
