import { Module } from '@nestjs/common';
import { ConfigModule } from '@nestjs/config';

import { DatabasePostgresService } from './postgres.service';

@Module({
  imports: [ConfigModule],
  providers: [DatabasePostgresService],
  exports: [DatabasePostgresService],
})
export class DatabasePostgresModule {}
