{
  "name": "{{ project_name | replace('_', '-') | lower }}",
  "version": "{{ app_version | default('1.0.0') }}",
  "description": "{{ description | default('NestJS application generated with RapidKit') }}",
  "license": "{{ license | default('Apache-2.0') }}",
  "author": "{{ author }}",
  "engines": {
    "node": ">={{ node_version }}"
  },
  "private": true,
  "scripts": {
    "start": "node dist/main",
    "dev": "nest start --watch",
    "start:dev": "nest start --watch",
    "start:debug": "nest start --debug --watch",
    "start:prod": "node dist/main",
    "build": "nest build",
    "lint": "eslint \"{src,test}/**/*.ts\" --fix",
    "format": "prettier --write \"src/**/*.ts\" \"test/**/*.ts\"",
    "test": "jest",
    "test:watch": "jest --watch",
    "test:cov": "jest --coverage",
    "test:e2e": "jest --config ./test/jest-e2e.json"
  },
  "dependencies": {
    "@nestjs/common": "^11.1.10",
    "@nestjs/config": "^4.0.2",
    "@nestjs/core": "^11.1.10",
    "@nestjs/platform-express": "^11.1.10",
    "@nestjs/swagger": "^11.2.3",
    "class-transformer": "^0.5.1",
    "class-validator": "^0.14.3",
    "reflect-metadata": "^0.2.2",
    "rxjs": "^7.8.2",
    "helmet": "^8.1.0",
    "compression": "^1.8.1",
    "winston": "^3.19.0",
    "joi": "^18.0.2",
    "@nestjs/terminus": "^11.0.0",
    {% if database_type in ['postgresql', 'mysql'] %}
    "@nestjs/typeorm": "^11.0.0",
    "typeorm": "^0.3.28",
    {% if database_type == 'postgresql' %}
    "pg": "^8.16.3",
    {% elif database_type == 'mysql' %}
    "mysql2": "^3.15.3",
    {% endif %}
    {% elif database_type == 'mongodb' %}
    "@nestjs/mongoose": "^11.0.3",
    "mongoose": "^9.0.1",
    {% endif %}
    {% if include_caching %}
    "@nestjs/cache-manager": "^3.0.1",
    "cache-manager": "^7.2.6",
    "cache-manager-redis-store": "^3.0.1",
    "ioredis": "^5.8.2",
    {% endif %}
    {% if include_monitoring %}
    "prom-client": "^15.1.3",
    {% endif %}
    {% if auth_type in ['jwt', 'oauth2'] %}
    "@nestjs/jwt": "^11.0.2",
    "@nestjs/passport": "^11.0.5",
    "bcrypt": "^6.0.0",
    "passport": "^0.7.0",
    "passport-jwt": "^4.0.1",
    {% endif %}
    "dotenv": "^17.2.3"
  },
  "devDependencies": {
    "@eslint/eslintrc": "^3.3.3",
    "@nestjs/cli": "^11.0.14",
    "@nestjs/schematics": "^11.0.9",
    "@nestjs/testing": "^11.1.10",
    "@types/compression": "^1.8.1",
    "@types/express": "^5.0.6",
    "@types/jest": "^30.0.0",
    "@types/node": "^18.19.130",
    "@types/supertest": "^6.0.3",
    "@typescript-eslint/eslint-plugin": "^8.50.1",
    "@typescript-eslint/parser": "^8.50.1",
    "eslint": "^9.39.2",
    "eslint-config-prettier": "^10.1.8",
    "eslint-plugin-import": "^2.32.0",
    "eslint-plugin-prettier": "^5.5.4",
    "jest": "^30.2.0",
    "prettier": "^3.7.4",
    "source-map-support": "^0.5.21",
    "supertest": "^7.1.4",
    "ts-jest": "^29.4.6",
    "ts-loader": "^9.5.4",
    "ts-node": "^10.9.2",
    "tsconfig-paths": "^4.2.0",
    "typescript": "^5.9.3"
  },
  "overrides": {
    "cross-spawn": "7.0.5",
    "glob": "10.5.0"
  }
}
