// Generated metadata controller for Users Core
import { Controller, Get } from '@nestjs/common';

@Controller('api/modules/users')
export class UsersCoreMetadataController {
  @Get('metadata')
  getMetadata() {
    return {
      name: 'users_core',
      features: ['user_lifecycle', 'user_directory', 'http_apis'],
    };
  }
}

export default UsersCoreMetadataController
