# Default MongoDB configuration generated by RapidKit
mongo:
  module: {{ rapidkit_vendor_module | tojson }}
  enabled: {{ enabled_by_default | tojson }}
  connection:
    uri: {{ mongo_defaults.get('connection_uri') | tojson }}
    database: {{ mongo_defaults.get('database') | tojson }}
    app_name: {{ mongo_defaults.get('app_name') | tojson }}
    auth_source: {{ mongo_defaults.get('auth_source') | tojson }}
    username: {{ mongo_defaults.get('username') | tojson }}
    password: {{ mongo_defaults.get('password') | tojson }}
    replica_set: {{ mongo_defaults.get('replica_set') | tojson }}
    read_preference: {{ mongo_defaults.get('read_preference') | tojson }}
    compressors: {{ mongo_defaults.get('compressors', []) | tojson(indent=2) }}
    retry_reads: {{ mongo_defaults.get('retry_reads') | tojson }}
    retry_writes: {{ mongo_defaults.get('retry_writes') | tojson }}
    connect_timeout_ms: {{ mongo_defaults.get('connect_timeout_ms') | tojson }}
    server_selection_timeout_ms: {{ mongo_defaults.get('server_selection_timeout_ms') | tojson }}
    max_idle_time_ms: {{ mongo_defaults.get('max_idle_time_ms') | tojson }}
  pool:
    min_size: {{ mongo_defaults.get('min_pool_size') | tojson }}
    max_size: {{ mongo_defaults.get('max_pool_size') | tojson }}
  security:
    tls: {{ mongo_defaults.get('tls') | tojson }}
    tls_allow_invalid_certificates: {{ mongo_defaults.get('tls_allow_invalid_certificates') | tojson }}
  health:
    ping_timeout_ms: {{ health_defaults.get('ping_timeout_ms') | tojson }}
    metrics: {{ health_defaults.get('metrics') | tojson }}
