import { Module } from "@nestjs/common";
import { ConfigModule } from "@nestjs/config";

import redisConfiguration from "./configuration";
import { {{ module_class_name }}Service } from "./redis.service";
import { {{ module_class_name }}Controller } from "./redis.controller";
import { {{ module_class_name }}HealthController } from "../../../../health/redis.health";

@Module({
  imports: [ConfigModule.forFeature(redisConfiguration)],
  controllers: [{{ module_class_name }}Controller, {{ module_class_name }}HealthController],
  providers: [{{ module_class_name }}Service],
  exports: [{{ module_class_name }}Service],
})
export class {{ module_class_name }}Module {}
