"""Core hooks for RapidKit.

This module contains hook functionality for:
- Framework-specific handlers
- Hook execution and management
"""

from typing import List as _List

__all__: _List[str] = []
