export * from "./{{ module_name }}.module";
export * from "./{{ module_name }}.service";
export * from "./{{ module_name }}.controller";
export * from "../../../../health/{{ module_name }}.health";
export * from "./{{ module_name }}.validation";
export * from "./configuration";
