# Notifications module environment variables
RAPIDKIT_NOTIFICATIONS_ENABLED={{ notifications_defaults.enabled | default(true) | tojson }}
RAPIDKIT_NOTIFICATIONS_LOG_LEVEL={{ notifications_defaults.log_level | default('INFO') }}
RAPIDKIT_NOTIFICATIONS_SMTP_HOST={{ notifications_defaults.smtp.host | default('localhost') }}
RAPIDKIT_NOTIFICATIONS_SMTP_PORT={{ notifications_defaults.smtp.port | default(587) }}
RAPIDKIT_NOTIFICATIONS_SMTP_USERNAME={{ notifications_defaults.smtp.username | default('') }}
RAPIDKIT_NOTIFICATIONS_SMTP_PASSWORD={{ notifications_defaults.smtp.password | default('') }}
RAPIDKIT_NOTIFICATIONS_SMTP_USE_TLS={{ notifications_defaults.smtp.use_tls | default(true) | tojson }}
RAPIDKIT_NOTIFICATIONS_SMTP_TIMEOUT={{ notifications_defaults.smtp.timeout | default(30) }}
RAPIDKIT_NOTIFICATIONS_SENDER_FROM_EMAIL={{ notifications_defaults.sender.from_email | default('noreply@rapidkit.local') }}
RAPIDKIT_NOTIFICATIONS_SENDER_FROM_NAME={{ notifications_defaults.sender.from_name | default('RapidKit Notifications') }}
RAPIDKIT_NOTIFICATIONS_SENDER_REPLY_TO={{ notifications_defaults.sender.reply_to | default('') }}
RAPIDKIT_NOTIFICATIONS_TEMPLATE_DIRECTORY={{ notifications_defaults.templates.directory | default('./templates/notifications') }}
RAPIDKIT_NOTIFICATIONS_TEMPLATE_AUTO_RELOAD={{ notifications_defaults.templates.auto_reload | default(false) | tojson }}
RAPIDKIT_NOTIFICATIONS_RETRY_MAX_ATTEMPTS={{ notifications_defaults.retry.max_attempts | default(3) }}
RAPIDKIT_NOTIFICATIONS_RETRY_BACKOFF_SECONDS={{ notifications_defaults.retry.backoff_seconds | default(2.0) }}
RAPIDKIT_NOTIFICATIONS_RETRY_INITIAL_DELAY_SECONDS={{ notifications_defaults.retry.initial_delay_seconds | default(1.0) }}
RAPIDKIT_NOTIFICATIONS_RATE_LIMIT_ENABLED={{ notifications_defaults.rate_limit.enabled | default(false) | tojson }}
RAPIDKIT_NOTIFICATIONS_RATE_LIMIT_MAX_PER_MINUTE={{ notifications_defaults.rate_limit.max_per_minute | default('') }}
RAPIDKIT_NOTIFICATIONS_RATE_LIMIT_MAX_PER_HOUR={{ notifications_defaults.rate_limit.max_per_hour | default('') }}
