import { Module } from "@nestjs/common";

import { {{ module_class_name }}Controller } from "./users-core.controller";
import { {{ module_class_name }}Service } from "./users-core.service";

@Module({
  controllers: [{{ module_class_name }}Controller],
  providers: [{{ module_class_name }}Service],
  exports: [{{ module_class_name }}Service],
})
export class {{ module_class_name }}Module {}
