{# Jinja snippet used to inject shared fragments into generated artefacts. #}
{# Name this snippet when referencing from module.yaml generation entries. #}

{% set module_name = "stripe_payment" %}

# Stripe Payment module quick actions
rapidkit module info stripe_payment
rapidkit module validate stripe_payment
