import { Controller, Get, HttpCode, HttpStatus } from "@nestjs/common";

import { {{ module_class_name }}Service, CorsHealthPayload } from "./cors.service";

@Controller("api/health/module")
export class {{ module_class_name }}HealthController {
  constructor(private readonly service: {{ module_class_name }}Service) {}

  @Get("{{ module_kebab }}")
  @HttpCode(HttpStatus.OK)
  getModuleHealth(): CorsHealthPayload {
    return this.service.getHealthPayload();
  }
}
