"""Project-facing shims that delegate to the vendor custom source implementations."""

from __future__ import annotations

from .settings import _load_vendor_module

_vendor = _load_vendor_module()

load_from_yaml = getattr(_vendor, "load_from_yaml")
load_from_vault = getattr(_vendor, "load_from_vault")
load_from_aws_sm = getattr(_vendor, "load_from_aws_sm")


__all__ = [
    "load_from_yaml",
    "load_from_vault",
    "load_from_aws_sm",
]
