"""Project shim delegating to the vendor hot reload implementation."""

from __future__ import annotations

from .settings import _load_vendor_module

_vendor = _load_vendor_module()

start_hot_reload = getattr(_vendor, "start_hot_reload")


__all__ = ["start_hot_reload"]
