import { Module } from '@nestjs/common';

import { RateLimitingModule } from '../modules/free/security/rate_limiting/rate-limiting.module';
import { RateLimitingHealthController } from './rate-limiting-health.controller';

@Module({
  imports: [RateLimitingModule],
  controllers: [RateLimitingHealthController],
})
export class RateLimitingHealthModule {}
