"""FastAPI router exports for the session module."""

from __future__ import annotations

from fastapi import APIRouter

from src.modules.free.auth.session.session import create_router as _create_session_router


def create_router(*, router: APIRouter | None = None) -> APIRouter:
    """Return the canonical Session router, allowing optional overrides."""

    return _create_session_router(router=router)


router = create_router()


__all__ = ["create_router", "router"]
