# Default Celery configuration generated by RapidKit
celery:
  module: {{ rapidkit_vendor_module | tojson }}
  name: {{ celery_defaults.get('name', 'rapidkit') | tojson }}
  namespace: {{ celery_defaults.get('namespace', 'CELERY') | tojson }}
  autodiscover: {{ celery_defaults.get('autodiscover', []) | tojson(indent=2) }}
  settings:
    broker_url: {{ celery_settings_defaults.get('broker_url', 'redis://localhost:6379/0') | tojson }}
    result_backend: {{ celery_settings_defaults.get('result_backend', 'redis://localhost:6379/1') | tojson }}
    timezone: {{ celery_settings_defaults.get('timezone', 'UTC') | tojson }}
    enable_utc: {{ celery_settings_defaults.get('enable_utc', True) | tojson }}
    task_default_queue: {{ celery_settings_defaults.get('task_default_queue', 'default') | tojson }}
    imports: {{ celery_settings_defaults.get('imports', []) | tojson(indent=2) }}
    include: {{ celery_settings_defaults.get('include', []) | tojson(indent=2) }}
    beat_schedule: {{ celery_settings_defaults.get('beat_schedule', {}) | tojson(indent=2) }}
    worker_max_tasks_per_child: {{ celery_settings_defaults.get('worker_max_tasks_per_child') | tojson }}
    result_expires: {{ celery_settings_defaults.get('result_expires', 3600) | tojson }}
