# Logging Module Environment Variables
{% set defaults = logging_defaults %}
LOG_LEVEL={{ defaults.level | default('INFO') }}
LOG_FORMAT={{ defaults.format | default('json') }}
LOG_SINKS={{ defaults.sinks | default(['stderr']) | tojson }}  # JSON list form (preferred). You can also set comma list via settings (e.g., ["stderr","file"]).
LOG_FILE_PATH={{ defaults.file_path | default('logs/app.log') }}
LOG_ASYNC_QUEUE={{ 'true' if defaults.async_queue | default(true) else 'false' }}
LOG_SAMPLING_RATE={{ defaults.sampling_rate | default(1.0) }}
LOG_ENABLE_REDACTION={{ 'true' if defaults.enable_redaction | default(true) else 'false' }}
OTEL_BRIDGE_ENABLED={{ 'true' if defaults.otel_bridge_enabled | default(false) else 'false' }}
METRICS_BRIDGE_ENABLED={{ 'true' if defaults.metrics_bridge_enabled | default(false) else 'false' }}
RAPIDKIT_LOGGING_REQUEST_CONTEXT={{ 'true' if defaults.enable_request_context | default(true) else 'false' }}
LOGGING_HEALTHCHECK_ENABLED={{ 'true' if defaults.healthcheck_enabled | default(true) else 'false' }}
LOGGING_HEALTHCHECK_PATH={{ defaults.healthcheck_path | default('/api/health/module/logging') }}
