# Passwordless Module Environment Variables
{% set defaults = passwordless_defaults %}
PASSWORDLESS_MAGIC_LINK_BASE_URL={{ defaults.magic_link_base_url | default('https://example.com/auth/passwordless') }}
PASSWORDLESS_TOKEN_TTL_SECONDS={{ defaults.token_ttl_seconds | default(900) }}
PASSWORDLESS_TOKEN_LENGTH={{ defaults.token_length | default(8) }}
PASSWORDLESS_RESEND_COOLDOWN_SECONDS={{ defaults.resend_cooldown_seconds | default(60) }}
PASSWORDLESS_MAX_ATTEMPTS={{ defaults.max_attempts | default(5) }}
PASSWORDLESS_DELIVERY_METHODS={{ defaults.delivery_methods | default(['email', 'sms']) | tojson }}
