# Application
APP_NAME={{ project_name | upper }}
PORT=8000
HOST=0.0.0.0
NODE_ENV=development

# Security
JWT_SECRET="{{ '' | generate_secret(48) }}"
JWT_EXPIRATION=1h

# Database
DATABASE_URL=postgresql://user:password@localhost:5432/{{ project_name | replace('-', '_') }}

# Redis
REDIS_HOST=localhost
REDIS_PORT=6379

# <<<inject:module-env>>>
