# Python build artifacts
__pycache__/
*.py[cod]
*.so
*.egg-info/
.eggs/
build/
dist/

# Node build artifacts
node_modules/
.next/
.npm/
yarn.lock
pnpm-lock.yaml

# Environment
.env
.env.*
!.env.example

# VCS
.git
.gitignore

# Editor settings
.vscode/
.idea/

# Local files
*.log
.DS_Store
