import { {{ module_class_name }}Service, HealthSnapshot } from "./{{ module_name }}.service";

export const runtimeHealth = (service: {{ module_class_name }}Service): HealthSnapshot => service.health();
