  RAPIDKIT_DB_SQLITE_PATH?: string;
  RAPIDKIT_DB_SQLITE_CREATE_IF_MISSING?: boolean;
  RAPIDKIT_DB_SQLITE_TIMEOUT_SECONDS?: number;
  RAPIDKIT_DB_SQLITE_POOL_MAX_SIZE?: number;
  RAPIDKIT_DB_SQLITE_POOL_RECYCLE_SECONDS?: number;
  RAPIDKIT_DB_SQLITE_PRAGMAS?: Record<string, unknown>;
