export * from "./users-profiles.module";
export * from "./users-profiles.service";
export * from "./users-profiles.controller";
export {
	USERS_PROFILES_CONFIGURATION_NAMESPACE,
	usersProfilesConfiguration,
} from "./users-profiles.configuration";
export type {
	UsersProfilesFeature,
	UsersProfilesHealthPayload,
	UsersProfilesMetadata,
	UserProfileDto,
	UpdateUserProfileDto,
} from "./users-profiles.service";
