"""Override contracts for Ai Assistant."""

from core.services.override_contracts import ConfigurableOverrideMixin


class AiAssistantOverrides(ConfigurableOverrideMixin):
    """Extend or customize generated behaviour for Ai Assistant."""

    # def custom_method(self, *args, **kwargs):
    #     """Example override."""
    #     original = self.call_original("custom_method", *args, **kwargs)
    #     return original
