{# Jinja snippet used to inject shared fragments into generated artefacts. #}
{# Name this snippet when referencing from module.yaml generation entries. #}

{% set module_name = "cart" %}

# TODO: Provide snippet content for {{ module_name }}
