"""Shared helpers reusable by multiple RapidKit scaffolding kits."""

from .settings_vendor import ensure_settings_vendor_snapshot, get_settings_vendor_metadata

__all__ = ["ensure_settings_vendor_snapshot", "get_settings_vendor_metadata"]
