# Default Deployment configuration generated by RapidKit
deployment:
  include_ci: {{ deployment_defaults.get('include_ci', True) | tojson }}
  include_postgres: {{ deployment_defaults.get('include_postgres', True) | tojson }}
  python_version: {{ deployment_defaults.get('python_version', '3.10') | tojson }}
  node_version: {{ deployment_defaults.get('node_version', '20.19.6') | tojson }}
  package_manager: {{ deployment_defaults.get('package_manager', 'npm') | tojson }}
  package_manager_command: {{ deployment_defaults.get('package_manager_command', 'npm') | tojson }}
