{# Jinja snippet used to inject shared fragments into generated artefacts. #}
{# Name this snippet when referencing from module.yaml generation entries. #}

{% set module_name = "db_sqlite" %}

# Db Sqlite module quick actions
rapidkit module info db_sqlite
rapidkit module validate db_sqlite
